@@ -216,6 +216,11 @@ impl<'a> Index<'a> {
     pub fn parse_sysv_index(buffer: &'a [u8]) -> Result<Self> {
         let offset = &mut 0;
         let sizeof_table = buffer.gread_with::<u32>(offset, scroll::BE)? as usize;
+
+        if sizeof_table > buffer.len() / 4 {
+            return Err(Error::BufferTooShort(sizeof_table, "indices"));
+        }
+
         let mut indexes = Vec::with_capacity(sizeof_table);
         for _ in 0..sizeof_table {
             indexes.push(buffer.gread_with::<u32>(offset, scroll::BE)?);
@@ -270,6 +275,10 @@ impl<'a> Index<'a> {
         let strtab_bytes = buffer.pread_with::<u32>(entries_bytes + 4, scroll::LE)? as usize;
         let strtab = strtab::Strtab::parse(buffer, entries_bytes + 8, strtab_bytes, 0x0)?;
 
+        if entries_bytes > buffer.len() {
+            return Err(Error::BufferTooShort(entries, "entries"));
+        }
+
         // build the index
         let mut indexes = Vec::with_capacity(entries);
         let mut strings = Vec::with_capacity(entries);
@@ -311,11 +320,22 @@ impl<'a> Index<'a> {
     pub fn parse_windows_linker_member(buffer: &'a [u8]) -> Result<Self> {
         let offset = &mut 0;
         let members = buffer.gread_with::<u32>(offset, scroll::LE)? as usize;
+
+        if members > buffer.len() / 4 {
+            return Err(Error::BufferTooShort(members, "members"));
+        }
+
         let mut member_offsets = Vec::with_capacity(members);
         for _ in 0..members {
             member_offsets.push(buffer.gread_with::<u32>(offset, scroll::LE)?);
         }
+
         let symbols = buffer.gread_with::<u32>(offset, scroll::LE)? as usize;
+
+        if symbols > buffer.len() / 2 {
+            return Err(Error::BufferTooShort(symbols, "symbols"));
+        }
+
         let mut symbol_offsets = Vec::with_capacity(symbols);
         for _ in 0..symbols {
             symbol_offsets
@@ -398,10 +418,6 @@ pub enum IndexType {
 #[derive(Debug)]
 /// An in-memory representation of a parsed Unix Archive
 pub struct Archive<'a> {
-    // we can chuck this because the symbol index is a better representation, but we keep for
-    // debugging
-    index: Index<'a>,
-    sysv_name_index: NameIndex<'a>,
     // The array of members, which are indexed by the members hash and symbol index.
     // These are in the same order they are found in the file.
     member_array: Vec<Member<'a>>,
@@ -409,8 +425,6 @@ pub struct Archive<'a> {
     members: BTreeMap<&'a str, usize>,
     // symbol -> member
     symbol_index: BTreeMap<&'a str, usize>,
-    /// Type of the symbol index that was found in the archive.
-    index_type: IndexType,
 }
 
 impl<'a> Archive<'a> {
@@ -506,12 +520,9 @@ impl<'a> Archive<'a> {
         }
 
         Ok(Archive {
-            index,
             member_array,
-            sysv_name_index,
             members,
             symbol_index,
-            index_type,
         })
     }
 
